################################################################################################################################
#
# Description:	This constraint file applies to hardware features that are unique to a specific model number within a
#				product family.
#
# Rev History: 	01-18-2016:	Inital release.
#
################################################################################################################################

###################################################### Timing Constraints ######################################################

# Set the RX/TX clock frequency to 310 MHz
create_clock -name rx_clk -period 3.226 [get_ports sample_clk_p]
set_clock_groups -name async_rx_clk -asynchronous -group [get_clocks rx_clk]

# Set a false path to the clock input buffer used for dynamic phase alignment.
set_false_path -through [get_pins XCVR/RX_CH.ADC/CLK_FORWARD[1].CLK_DDR/D]

###################################################### Pinout Constraints ######################################################
# Note: The external component and pin name connected to each PACKAGE_PIN is shown as a comment (#component:pin).

# Sample clock generated by the frequency synthesizer.
set_property PACKAGE_PIN G22 [get_ports sample_clk_p];  #LMK01000:CLKOUT0P

# RX1/RX2 pin assignments.
set_property PACKAGE_PIN K25 [get_ports {rx1to2_data_in_p[0]}];  #AD9652:D[0]+
set_property PACKAGE_PIN M25 [get_ports {rx1to2_data_in_p[1]}];  #AD9652:D[1]+
set_property PACKAGE_PIN M24 [get_ports {rx1to2_data_in_p[2]}];  #AD9652:D[2]+
set_property PACKAGE_PIN M21 [get_ports {rx1to2_data_in_p[3]}];  #AD9652:D[3]+
set_property PACKAGE_PIN N19 [get_ports {rx1to2_data_in_p[4]}];  #AD9652:D[4]+
set_property PACKAGE_PIN N26 [get_ports {rx1to2_data_in_p[5]}];  #AD9652:D[5]+
set_property PACKAGE_PIN N21 [get_ports {rx1to2_data_in_p[6]}];  #AD9652:D[6]+
set_property PACKAGE_PIN P23 [get_ports {rx1to2_data_in_p[7]}];  #AD9652:D[7]+
set_property PACKAGE_PIN P24 [get_ports {rx1to2_data_in_p[8]}];  #AD9652:D[8]+
set_property PACKAGE_PIN P19 [get_ports {rx1to2_data_in_p[9]}];  #AD9652:D[9]+
set_property PACKAGE_PIN R25 [get_ports {rx1to2_data_in_p[10]}];  #AD9652:D[10]+
set_property PACKAGE_PIN R26 [get_ports {rx1to2_data_in_p[11]}];  #AD9652:D[11]+
set_property PACKAGE_PIN R22 [get_ports {rx1to2_data_in_p[12]}];  #AD9652:D[12]+
set_property PACKAGE_PIN U19 [get_ports {rx1to2_data_in_p[13]}];  #AD9652:D[13]+
set_property PACKAGE_PIN T20 [get_ports {rx1to2_data_in_p[14]}];  #AD9652:D[14]+
set_property PACKAGE_PIN T22 [get_ports {rx1to2_data_in_p[15]}];  #AD9652:D[15]+
set_property PACKAGE_PIN T24 [get_ports rx1to2_ovr_in_p];  #AD9652:OR+

# RX1/RX2 clock forward pin assignment.
set_property PACKAGE_PIN R21 [get_ports rx1to2_clk_in_p];  #ADS42LB69:DCO+

# TX3/TX4 pin assignments.
set_property PACKAGE_PIN AF24 [get_ports {tx3to4_data_out_p[0]}];  #AD9142A:D[0]P
set_property PACKAGE_PIN AD26 [get_ports {tx3to4_data_out_p[1]}];  #AD9142A:D[1]P
set_property PACKAGE_PIN AD25 [get_ports {tx3to4_data_out_p[2]}];  #AD9142A:D[2]P
set_property PACKAGE_PIN AD23 [get_ports {tx3to4_data_out_p[3]}];  #AD9142A:D[3]P
set_property PACKAGE_PIN AC23 [get_ports {tx3to4_data_out_p[4]}];  #AD9142A:D[4]P
set_property PACKAGE_PIN AB26 [get_ports {tx3to4_data_out_p[5]}];  #AD9142A:D[5]P
set_property PACKAGE_PIN AB22 [get_ports {tx3to4_data_out_p[6]}];  #AD9142A:D[6]P
set_property PACKAGE_PIN AA25 [get_ports {tx3to4_data_out_p[7]}];  #AD9142A:D[7]P
set_property PACKAGE_PIN Y22 [get_ports {tx3to4_data_out_p[8]}];  #AD9142A:D[8]P
set_property PACKAGE_PIN Y23 [get_ports {tx3to4_data_out_p[9]}];  #AD9142A:D[9]P
set_property PACKAGE_PIN Y25 [get_ports {tx3to4_data_out_p[10]}];  #AD9142A:D[10]P
set_property PACKAGE_PIN W23 [get_ports {tx3to4_data_out_p[11]}];  #AD9142A:D[11]P
set_property PACKAGE_PIN W25 [get_ports {tx3to4_data_out_p[12]}];  #AD9142A:D[12]P
set_property PACKAGE_PIN U22 [get_ports {tx3to4_data_out_p[13]}];  #AD9142A:D[13]P
set_property PACKAGE_PIN V23 [get_ports {tx3to4_data_out_p[14]}];  #AD9142A:D[14]P
set_property PACKAGE_PIN U24 [get_ports {tx3to4_data_out_p[15]}];  #AD9142A:D[15]P
set_property PACKAGE_PIN U26 [get_ports {tx3to4_frame_p}];  #AD9142A:FRAMEP
set_property PACKAGE_PIN H18 [get_ports {tx3to4_enable}];  #AD9142A:TXEN

# TX3/TX4 clock forward pin assignment.
set_property PACKAGE_PIN AA23 [get_ports tx3to4_clk_out_p];  #AD9142A:DCIP
